/* this is mutex.c file, part of the libspopc library sources
 * copyright © 2002- Benoit Rouits <brouits@free.fr>
 * released under the terms of the GNU Lesser General Public Licence.
 *
 * libspopc offers simple API for a pop3 client.
 * See RFC 1725 for pop3 specifications.
 * more information on http://brouits.free.fr/libspopc/
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include <semaphore.h>
#include "mutex.h"

/* initializes a thread-wide mutex */
int mutex_init(mutex* id)
{
	return sem_init(id, 0, 1);
}

/* acquire the given mutex to enter in a critical section */
int mutex_in (mutex* id)
{
	return sem_wait(id);
	/* this is a blocking call */
}

/* quit the critical section, by releasing the given mutex */
int mutex_out (mutex* id)
{
	return sem_post(id);
}

/* clean given mutex, thus re-initable by mutex_init() */
int mutex_clean(mutex* id)
{
	return sem_destroy(id);
}

